docx\_parser\_converter.docx\_parsers.helpers.common\_helpers module
====================================================================

.. automodule:: docx_parser_converter.docx_parsers.helpers.common_helpers
   :members:
   :undoc-members:
   :show-inheritance:
